@@ -2,7 +2,7 @@
 %% vim: ts=4 sw=4 ft=erlang noet
 %%%-------------------------------------------------------------------
 %%% @author Andrew Bennett <potatosaladx@gmail.com>
-%%% @copyright 2014-2015, Andrew Bennett
+%%% @copyright 2014-2022, Andrew Bennett
 %%% @doc
 %%%
 %%% @end
@@ -153,13 +153,13 @@ support_check() ->
 	Entries = lists:flatten(lists:foldl(fun(Check, Acc) ->
 		Check(Fallback, Acc)
 	end, [], [
+		fun check_sha3/2,
 		fun check_ec_key_mode/2,
 		fun check_chacha20_poly1305/2,
 		fun check_xchacha20_poly1305/2,
 		fun check_curve25519/2,
 		fun check_curve448/2,
 		fun check_json/2,
-		fun check_sha3/2,
 		fun check_crypto/2,
 		fun check_public_key/2
 	])),
@@ -173,9 +173,7 @@ support_check() ->
 
 %% @private
 check_ec_key_mode(_Fallback, Entries) ->
-	ECPEMEntry = {
-		'ECPrivateKey',
-		<<
+	PEMBin = <<
 			48,119,2,1,1,4,32,104,152,88,12,19,82,251,156,171,31,222,207,
 			0,76,115,88,210,229,36,106,137,192,81,153,154,254,226,38,247,
 			70,226,157,160,10,6,8,42,134,72,206,61,3,1,7,161,68,3,66,0,4,
@@ -184,13 +182,23 @@ check_ec_key_mode(_Fallback, Entries) ->
 			36,225,0,90,21,186,235,132,152,229,13,189,196,121,64,84,64,
 			229,173,12,24,23,127,175,67,247,29,139,91
 		>>,
-		not_encrypted
-	},
-	case public_key:pem_entry_decode(ECPEMEntry) of
-		#'ECPrivateKey'{ privateKey = PrivateKey, publicKey = PublicKey } when is_list(PrivateKey) andalso is_tuple(PublicKey) ->
-			[{ec_key_mode, list} | Entries];
-		#'ECPrivateKey'{ privateKey = PrivateKey, publicKey = PublicKey } when is_binary(PrivateKey) andalso is_binary(PublicKey) ->
-			[{ec_key_mode, binary} | Entries]
+	PEMEntry = {'ECPrivateKey', PEMBin, not_encrypted},
+	%% Erlang 24 changes 'ECPrivateKey' record in a way that makes record matching fail
+	%% when this module is compiled on Erlang 23 (or earlier) but runs on 24.
+	%% So we destructure tuples, as ugly as it may be.
+	%%
+	%% See erlang-jose#113 for details.
+	PrivateKey = case list_to_integer(erlang:system_info(otp_release)) >= 24 of
+		true ->
+			{'ECPrivateKey', _Version, PrivKey0, _Params, _PubKey0, _Attributes} = public_key:pem_entry_decode(PEMEntry),
+			PrivKey0;
+		false ->
+			{'ECPrivateKey', _Version, PrivKey0, _Params, _PubKey0} = public_key:pem_entry_decode(PEMEntry),
+			PrivKey0
+	end,
+	case is_binary(PrivateKey) of
+		true -> [{ec_key_mode, binary} | Entries];
+		_    -> [{ec_key_mode, list} | Entries]
 	end.
 
 %% @private
@@ -212,6 +220,8 @@ check_chacha20_poly1305(Fallback, Entries) ->
 					check_chacha20_poly1305_module(M)
 			end
 	end,
+	%% Potentially used by XChaCha20-Poly1305 related functions below, needs to be inserted early.
+	true = ets:insert(?TAB, {chacha20_poly1305_module, ChaCha20Poly1305Module}),
 	[{chacha20_poly1305_module, ChaCha20Poly1305Module} | Entries].
 
 %% @private
@@ -269,7 +279,7 @@ check_curve25519(Fallback, Entries) ->
 		[] ->
 			case application:get_env(jose, curve25519_module, undefined) of
 				undefined ->
-					check_curve25519_modules(Fallback, [libdecaf, libsodium]);
+					check_curve25519_modules(Fallback, [libdecaf, libsodium, crypto]);
 				M when is_atom(M) ->
 					check_curve25519_module(M)
 			end
@@ -277,6 +287,8 @@ check_curve25519(Fallback, Entries) ->
 	[{curve25519_module, Curve25519Module} | Entries].
 
 %% @private
+check_curve25519_module(crypto) ->
+	jose_curve25519_crypto;
 check_curve25519_module(libdecaf) ->
 	jose_curve25519_libdecaf;
 check_curve25519_module(libsodium) ->
@@ -289,13 +301,45 @@ check_curve25519_modules(Fallback, [Module | Modules]) ->
 	case code:ensure_loaded(Module) of
 		{module, Module} ->
 			_ = application:ensure_all_started(Module),
-			check_curve25519_module(Module);
+			RealFallback = jose_jwa_curve25519,
+			RealModule = check_curve25519_module(Module),
+			try check_curve25519_module_does_it_work(RealFallback, RealModule) of
+				true ->
+					RealModule;
+				false ->
+					check_curve25519_modules(Fallback, Modules)
+			catch _Class:_Reason:_Stacktrace ->
+				% io:format("Class = ~p~nReason = ~p~nStacktrace = ~p~n", [Class, Reason, Stacktrace]),
+				check_curve25519_modules(Fallback, Modules)
+			end;
 		_ ->
 			check_curve25519_modules(Fallback, Modules)
 	end;
 check_curve25519_modules(Fallback, []) ->
 	Fallback.
 
+%% @private
+check_curve25519_module_does_it_work(Fallback, Module) ->
+	{PK, SK = <<Secret:32/binary, _:32/binary>>} = Module:eddsa_keypair(),
+	{PK, SK} = Module:eddsa_keypair(Secret),
+	PK = Module:eddsa_secret_to_public(Secret),
+	Message = crypto:strong_rand_bytes(16),
+	Signature = Module:ed25519_sign(Message, SK),
+	true = Module:ed25519_verify(Signature, Message, PK),
+	true = Fallback:ed25519_verify(Signature, Message, PK),
+	%% NOTE: Ed25519ctx and Ed25519ph are lower priority, no need to check for now.
+	% Ctx = <<"ctx">>,
+	% CtxSignature = Module:ed25519ctx_sign(Message, SK, Ctx),
+	% true = Module:ed25519ctx_verify(CtxSignature, Message, PK, Ctx),
+	% true = Fallback:ed25519ctx_verify(CtxSignature, Message, PK, Ctx),
+	% PHSignature = Module:ed25519ph_sign(Message, SK),
+	% true = Module:ed25519ph_verify(PHSignature, Message, PK),
+	% true = Fallback:ed25519ph_verify(PHSignature, Message, PK),
+	% CtxPHSignature = Module:ed25519ph_sign(Message, SK, Ctx),
+	% true = Module:ed25519ph_verify(CtxPHSignature, Message, PK, Ctx),
+	% true = Fallback:ed25519ph_verify(CtxPHSignature, Message, PK, Ctx),
+	true.
+
 %% @private
 check_curve448(false, Entries) ->
 	check_curve448(jose_curve448_unsupported, Entries);
@@ -310,7 +354,7 @@ check_curve448(Fallback, Entries) ->
 		[] ->
 			case application:get_env(jose, curve448_module, undefined) of
 				undefined ->
-					check_curve448_modules(Fallback, [libdecaf]);
+					check_curve448_modules(Fallback, [libdecaf, crypto]);
 				M when is_atom(M) ->
 					check_curve448_module(M)
 			end
@@ -318,6 +362,8 @@ check_curve448(Fallback, Entries) ->
 	[{curve448_module, Curve448Module} | Entries].
 
 %% @private
+check_curve448_module(crypto) ->
+	jose_curve448_crypto;
 check_curve448_module(libdecaf) ->
 	jose_curve448_libdecaf;
 check_curve448_module(Module) when is_atom(Module) ->
@@ -328,13 +374,45 @@ check_curve448_modules(Fallback, [Module | Modules]) ->
 	case code:ensure_loaded(Module) of
 		{module, Module} ->
 			_ = application:ensure_all_started(Module),
-			check_curve448_module(Module);
+			RealFallback = jose_jwa_curve448,
+			RealModule = check_curve448_module(Module),
+			try check_curve448_module_does_it_work(RealFallback, RealModule) of
+				true ->
+					RealModule;
+				false ->
+					check_curve448_modules(Fallback, Modules)
+			catch _Class:_Reason:_Stacktrace ->
+				% io:format("Class = ~p~nReason = ~p~nStacktrace = ~p~n", [_Class, _Reason, _Stacktrace]),
+				check_curve448_modules(Fallback, Modules)
+			end;
 		_ ->
 			check_curve448_modules(Fallback, Modules)
 	end;
 check_curve448_modules(Fallback, []) ->
 	Fallback.
 
+%% @private
+check_curve448_module_does_it_work(Fallback, Module) ->
+	{PK, SK = <<Secret:57/binary, _:57/binary>>} = Module:eddsa_keypair(),
+	{PK, SK} = Module:eddsa_keypair(Secret),
+	PK = Module:eddsa_secret_to_public(Secret),
+	Message = crypto:strong_rand_bytes(16),
+	Signature = Module:ed448_sign(Message, SK),
+	true = Module:ed448_verify(Signature, Message, PK),
+	true = Fallback:ed448_verify(Signature, Message, PK),
+	%% NOTE: Ed448ph is lower priority, no need to check for now.
+	% Ctx = <<"ctx">>,
+	% CtxSignature = Module:ed448_sign(Message, SK, Ctx),
+	% true = Module:ed448_verify(CtxSignature, Message, PK, Ctx),
+	% true = Fallback:ed448_verify(CtxSignature, Message, PK, Ctx),
+	% PHSignature = Module:ed448ph_sign(Message, SK),
+	% true = Module:ed448ph_verify(PHSignature, Message, PK),
+	% true = Fallback:ed448ph_verify(PHSignature, Message, PK),
+	% CtxPHSignature = Module:ed448ph_sign(Message, SK, Ctx),
+	% true = Module:ed448ph_verify(CtxPHSignature, Message, PK, Ctx),
+	% true = Fallback:ed448ph_verify(CtxPHSignature, Message, PK, Ctx),
+	true.
+
 %% @private
 check_json(_Fallback, Entries) ->
 	JSONModule = case ets:lookup(?TAB, json_module) of
@@ -345,9 +423,9 @@ check_json(_Fallback, Entries) ->
 				undefined ->
 					case code:ensure_loaded(elixir) of
 						{module, elixir} ->
-							check_json_modules([ojson, 'Elixir.Jason', 'Elixir.Poison', jiffy, jsone, jsx]);
+							check_json_modules([ojson, 'Elixir.Jason', 'Elixir.Poison', jiffy, jsone, jsx, thoas]);
 						_ ->
-							check_json_modules([ojson, jiffy, jsone, jsx])
+							check_json_modules([ojson, jiffy, jsone, jsx, thoas])
 					end;
 				M when is_atom(M) ->
 					check_json_module(M)
@@ -364,6 +442,8 @@ check_json_module(jsone) ->
 	jose_json_jsone;
 check_json_module(ojson) ->
 	jose_json_ojson;
+check_json_module(thoas) ->
+	jose_json_thoas;
 check_json_module('Elixir.Jason') ->
 	jose_json_jason;
 check_json_module('Elixir.Poison') ->
@@ -433,11 +513,13 @@ check_sha3(Fallback, Entries) ->
 		[] ->
 			case application:get_env(jose, sha3_module, undefined) of
 				undefined ->
-					check_sha3_modules(Fallback, [keccakf1600, libdecaf]);
+					check_sha3_modules(Fallback, [libdecaf, keccakf1600]);
 				M when is_atom(M) ->
 					check_sha3_module(M)
 			end
 	end,
+	%% Potentially used by Ed448 related functions below, needs to be inserted early.
+	true = ets:insert(?TAB, {sha3_module, SHA3Module}),
 	[{sha3_module, SHA3Module} | Entries].
 
 %% @private
@@ -590,7 +672,7 @@ check_xchacha20_poly1305(Fallback, Entries) ->
 		[] ->
 			case application:get_env(jose, xchacha20_poly1305_module, undefined) of
 				undefined ->
-					check_xchacha20_poly1305_modules(Fallback, [crypto]);
+					check_xchacha20_poly1305_modules(Fallback, [libsodium, crypto]);
 				M when is_atom(M) ->
 					check_xchacha20_poly1305_module(M)
 			end
@@ -600,6 +682,8 @@ check_xchacha20_poly1305(Fallback, Entries) ->
 %% @private
 check_xchacha20_poly1305_module(crypto) ->
 	jose_xchacha20_poly1305_crypto;
+check_xchacha20_poly1305_module(libsodium) ->
+	jose_xchacha20_poly1305_libsodium;
 check_xchacha20_poly1305_module(Module) when is_atom(Module) ->
 	Module.
 
