@@ -16,6 +16,7 @@
 
 %% Tests.
 -export([encrypt_and_decrypt/1]).
+-export([kty_ec_from_der_and_to_der/1]).
 -export([kty_ec_from_map_and_to_map/1]).
 -export([kty_ec_from_pem_and_to_pem/1]).
 -export([kty_ec_box_encrypt_and_box_decrypt/1]).
@@ -23,23 +24,28 @@
 -export([kty_oct_from_map_and_to_map/1]).
 -export([kty_oct_block_encrypt_and_block_decrypt/1]).
 -export([kty_oct_sign_and_verify/1]).
+-export([kty_okp_ed25519_from_der_and_to_der/1]).
 -export([kty_okp_ed25519_from_map_and_to_map/1]).
 -export([kty_okp_ed25519_from_pem_and_to_pem/1]).
 -export([kty_okp_ed25519_sign_and_verify/1]).
 -export([kty_okp_ed25519ph_from_map_and_to_map/1]).
 -export([kty_okp_ed25519ph_sign_and_verify/1]).
+-export([kty_okp_ed448_from_der_and_to_der/1]).
 -export([kty_okp_ed448_from_map_and_to_map/1]).
 -export([kty_okp_ed448_from_pem_and_to_pem/1]).
 -export([kty_okp_ed448_sign_and_verify/1]).
 -export([kty_okp_ed448ph_from_map_and_to_map/1]).
 -export([kty_okp_ed448ph_sign_and_verify/1]).
+-export([kty_okp_x25519_from_der_and_to_der/1]).
 -export([kty_okp_x25519_from_map_and_to_map/1]).
 -export([kty_okp_x25519_from_pem_and_to_pem/1]).
 -export([kty_okp_x25519_box_encrypt_and_box_decrypt/1]).
+-export([kty_okp_x448_from_der_and_to_der/1]).
 -export([kty_okp_x448_from_map_and_to_map/1]).
 -export([kty_okp_x448_from_pem_and_to_pem/1]).
 -export([kty_okp_x448_box_encrypt_and_box_decrypt/1]).
 -export([kty_rsa_convert_sfm_to_crt/1]).
+-export([kty_rsa_from_der_and_to_der/1]).
 -export([kty_rsa_from_map_and_to_map/1]).
 -export([kty_rsa_from_pem_and_to_pem/1]).
 -export([kty_rsa_block_encrypt_and_block_decrypt/1]).
@@ -67,6 +73,7 @@ groups() ->
 			encrypt_and_decrypt
 		]},
 		{jose_jwk_kty_ec, [parallel], [
+			kty_ec_from_der_and_to_der,
 			kty_ec_from_map_and_to_map,
 			kty_ec_from_pem_and_to_pem,
 			kty_ec_box_encrypt_and_box_decrypt,
@@ -78,6 +85,7 @@ groups() ->
 			kty_oct_sign_and_verify
 		]},
 		{jose_jwk_kty_okp_ed25519, [parallel], [
+			kty_okp_ed25519_from_der_and_to_der,
 			kty_okp_ed25519_from_map_and_to_map,
 			kty_okp_ed25519_from_pem_and_to_pem,
 			kty_okp_ed25519_sign_and_verify
@@ -87,6 +95,7 @@ groups() ->
 			kty_okp_ed25519ph_sign_and_verify
 		]},
 		{jose_jwk_kty_okp_ed448, [parallel], [
+			kty_okp_ed448_from_der_and_to_der,
 			kty_okp_ed448_from_map_and_to_map,
 			kty_okp_ed448_from_pem_and_to_pem,
 			kty_okp_ed448_sign_and_verify
@@ -96,17 +105,20 @@ groups() ->
 			kty_okp_ed448ph_sign_and_verify
 		]},
 		{jose_jwk_kty_okp_x25519, [parallel], [
+			kty_okp_x25519_from_der_and_to_der,
 			kty_okp_x25519_from_map_and_to_map,
 			kty_okp_x25519_from_pem_and_to_pem,
 			kty_okp_x25519_box_encrypt_and_box_decrypt
 		]},
 		{jose_jwk_kty_okp_x448, [parallel], [
+			kty_okp_x448_from_der_and_to_der,
 			kty_okp_x448_from_map_and_to_map,
 			kty_okp_x448_from_pem_and_to_pem,
 			kty_okp_x448_box_encrypt_and_box_decrypt
 		]},
 		{jose_jwk_kty_rsa, [parallel], [
 			kty_rsa_convert_sfm_to_crt,
+			kty_rsa_from_der_and_to_der,
 			kty_rsa_from_map_and_to_map,
 			kty_rsa_from_pem_and_to_pem,
 			kty_rsa_block_encrypt_and_block_decrypt,
@@ -143,6 +155,11 @@ encrypt_and_decrypt(Config) ->
 		jose_jwk_props:prop_encrypt_and_decrypt(),
 		Config).
 
+kty_ec_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_ec_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_ec_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_ec_props:prop_from_map_and_to_map(),
@@ -178,6 +195,11 @@ kty_oct_sign_and_verify(Config) ->
 		jose_jwk_kty_oct_props:prop_sign_and_verify(),
 		Config).
 
+kty_okp_ed25519_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_okp_ed25519_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_okp_ed25519_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_okp_ed25519_props:prop_from_map_and_to_map(),
@@ -203,6 +225,11 @@ kty_okp_ed25519ph_sign_and_verify(Config) ->
 		jose_jwk_kty_okp_ed25519ph_props:prop_sign_and_verify(),
 		Config).
 
+kty_okp_ed448_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_okp_ed448_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_okp_ed448_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_okp_ed448_props:prop_from_map_and_to_map(),
@@ -228,6 +255,11 @@ kty_okp_ed448ph_sign_and_verify(Config) ->
 		jose_jwk_kty_okp_ed448ph_props:prop_sign_and_verify(),
 		Config).
 
+kty_okp_x25519_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_okp_x25519_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_okp_x25519_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_okp_x25519_props:prop_from_map_and_to_map(),
@@ -243,6 +275,11 @@ kty_okp_x25519_box_encrypt_and_box_decrypt(Config) ->
 		jose_jwk_kty_okp_x25519_props:prop_box_encrypt_and_box_decrypt(),
 		Config).
 
+kty_okp_x448_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_okp_x448_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_okp_x448_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_okp_x448_props:prop_from_map_and_to_map(),
@@ -263,6 +300,11 @@ kty_rsa_convert_sfm_to_crt(Config) ->
 		jose_jwk_kty_rsa_props:prop_convert_sfm_to_crt(),
 		Config).
 
+kty_rsa_from_der_and_to_der(Config) ->
+	ct_property_test:quickcheck(
+		jose_jwk_kty_rsa_props:prop_from_der_and_to_der(),
+		Config).
+
 kty_rsa_from_map_and_to_map(Config) ->
 	ct_property_test:quickcheck(
 		jose_jwk_kty_rsa_props:prop_from_map_and_to_map(),
