@@ -2,9 +2,9 @@
 %% vim: ts=4 sw=4 ft=erlang noet
 -module(jose_jwa_aes_kw_props).
 
--include_lib("triq/include/triq.hrl").
+-include_lib("proper/include/proper.hrl").
 
--compile(export_all).
+% -compile(export_all).
 
 kek_size() -> oneof([128, 192, 256]).
 
